@@ -15,11 +15,11 @@ from argparse import ArgumentParser
 from argparse import ArgumentTypeError
 from unittest import mock
 
+import io
 import json
 
 # noinspection PyPackageRequirements
 # noinspection PyPackageRequirements
-import six
 from testtools import ExpectedException
 
 from vitrageclient.common.formatters import DOTFormatter
@@ -158,7 +158,7 @@ strict digraph  {
 }
 '''  # noqa
 
-GRAPHML_DATA = u'''\
+GRAPHML_DATA = '''\
 <?xml version='1.0' encoding='utf-8'?>
 <graphml xmlns="http://graphml.graphdrawing.org/xmlns" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://graphml.graphdrawing.org/xmlns http://graphml.graphdrawing.org/xmlns/1.0/graphml.xsd">
   <key attr.name="size" attr.type="int" for="node" id="d20" />
@@ -337,7 +337,7 @@ class TopologyShowTest(CliTestCase):
         def dict2columns(data):
             return zip(*sorted(data.items()))
 
-        out = six.StringIO()
+        out = io.StringIO()
         formatter = DOTFormatter()
         topology = json.loads(JSON_DATA)
         columns, topology = dict2columns(topology)
@@ -350,7 +350,7 @@ class TopologyShowTest(CliTestCase):
         def dict2columns(data):
             return zip(*sorted(data.items()))
 
-        out = six.BytesIO()
+        out = io.BytesIO()
         formatter = GraphMLFormatter()
         topology = json.loads(JSON_DATA)
         columns, topology = dict2columns(topology)
